@@ -39,12 +39,7 @@ class Notebook(object):
         hdf_file = str(hdf_file) + ".h5"
         if Path(hdf_file).exists():
             hdf = FileHDFio(hdf_file)
-            custom_dict = GenericParameters()
-            for k, v in zip(
-                hdf[folder + "/input/custom_dict/data_dict"]["Parameter"],
-                hdf[folder + "/input/custom_dict/data_dict"]["Value"],
-            ):
-                custom_dict[k] = v
+            custom_dict = hdf[folder + '/input/custom_dict/data']
             custom_dict["project_dir"] = str(project_folder)
             return custom_dict
         elif Path("input.json").exists():
