@@ -159,7 +159,6 @@ class GenericJob(JobCore):
         self._server = Server()
         self._logger = s.logger
         self._executable = None
-        self._import_directory = None
         self._status = JobStatus(db=project.db, job_id=self.job_id)
         self.refresh_job_status()
         self._restart_file_list = list()
@@ -374,7 +373,7 @@ class GenericJob(JobCore):
         Returns:
             str: absolute path to the working directory
         """
-        if self._import_directory:
+        if self._import_directory is not None:
             return self._import_directory
         elif not self.project_hdf5.working_directory:
             self._create_working_directory()
@@ -990,13 +989,12 @@ class GenericJob(JobCore):
             memory_max=self.server.memory_limit,
             command=command,
         )
-        if que_id != None:
+        if que_id is not None:
             self.server.queue_id = que_id
             self._server.to_hdf(self._hdf5)
             print("Queue system id: ", que_id)
         else:
             self._logger.warning("Job aborted")
-            self._logger.warning(e.output)
             self.status.aborted = True
             raise ValueError("run_queue.sh crashed")
         s.logger.debug("submitted %s", self.job_name)
@@ -1282,7 +1280,7 @@ class GenericJob(JobCore):
         Returns:
 
         """
-        if not self.job_id:
+        if self.job_id is None:
             self.save()
         if job_name is None:
             job_name = "{}_restart".format(self.job_name)
@@ -1540,7 +1538,7 @@ class GenericJob(JobCore):
         """
         Internal helper function to koad the executable object, if it was not loaded already.
         """
-        if not self._executable or enforce:
+        if self._executable is None or enforce:
             if len(self.__module__.split(".")) > 1:
                 self._executable = Executable(
                     codename=self.__name__,
